@@ -30,7 +30,8 @@ from threading import Lock
 from itertools import product
 from functools import reduce
 from datetime import datetime
-import git
+if __os.uname()[4][:3] != 'arm':
+    import git
 import re
 from pathlib import Path
 
@@ -287,54 +288,57 @@ def doesFunctionContainsExplicitReturn(functionCall):
 
 def downloadProjectAsModuleFromGithub(moduleName, category, githubURL):
     try:
-        ht.__createModule__(moduleName, category)
-        moduleDir = __os.path.join( __path, 'modules', category, moduleName.replace('ht_', '') )
-        if __os.path.isdir( moduleDir ):
-            # Name for the new module-git
-            name_git_folder = githubURL.split('/')[-1].replace('.git', '')
-            # Get the dir path
-            actual_git_folder = __os.path.join( moduleDir, name_git_folder )
-            # Remove if exists
-            if __os.path.isdir( actual_git_folder ):
-                __os.remove( actual_git_folder )
-            # Git clone
-            git.Git( moduleDir ).clone( githubURL )
-            # Create new name
-            new_git_folder = __os.path.join( moduleDir, '_'.join( [ moduleName, 'git' ] ) )
-            # Rename the folder
-            if __os.path.isdir( new_git_folder ):
-                __os.remove( new_git_folder )
-                
-            __os.rename( actual_git_folder, new_git_folder )
-            # Get all files in directory
-            entries = __os.listdir(new_git_folder)
-            for ent in entries:
-                # Check files for remove not interesting ones
-                if ent.endswith('.md') or ent.endswith('.jpg') or ent.endswith('.png') or ent.endswith('.txt'):
-                    __os.remove( __os.path.join( new_git_folder, ent ) )
+        if __os.uname()[4][:3] != 'arm':
+            ht.__createModule__(moduleName, category)
+            moduleDir = __os.path.join( __path, 'modules', category, moduleName.replace('ht_', '') )
+            if __os.path.isdir( moduleDir ):
+                # Name for the new module-git
+                name_git_folder = githubURL.split('/')[-1].replace('.git', '')
+                # Get the dir path
+                actual_git_folder = __os.path.join( moduleDir, name_git_folder )
+                # Remove if exists
+                if __os.path.isdir( actual_git_folder ):
+                    __os.remove( actual_git_folder )
+                # Git clone
+                git.Git( moduleDir ).clone( githubURL )
+                # Create new name
+                new_git_folder = __os.path.join( moduleDir, '_'.join( [ moduleName, 'git' ] ) )
+                # Rename the folder
+                if __os.path.isdir( new_git_folder ):
+                    __os.remove( new_git_folder )
+                    
+                __os.rename( actual_git_folder, new_git_folder )
+                # Get all files in directory
+                entries = __os.listdir(new_git_folder)
+                for ent in entries:
+                    # Check files for remove not interesting ones
+                    if ent.endswith('.md') or ent.endswith('.jpg') or ent.endswith('.png') or ent.endswith('.txt'):
+                        __os.remove( __os.path.join( new_git_folder, ent ) )
 
-            # Search for setup.py if there is
-            entries = __os.listdir(new_git_folder)
-            for filen in entries:
-                file_to_read = __os.path.join( new_git_folder, filen )
-                setup_content = readFileAsString( file_to_read )
-                commands = []
-                find_for = [ '--' ]
-                for finding in find_for:
-                    if finding in setup_content:
-                        for ind in findIndexAllOccurrencesSubstring(finding, str( setup_content )):
-                            interesting_line = str(setup_content)[ind:].split('\n')[0]
-                            for appearances in interesting_line.split( finding ):
-                                comm = ''.join( [ finding, appearances.split('\'')[0] ] ).split(' ')[0]
-                                if not comm in commands and not comm == finding:
-                                    commands.append( comm )
-                if commands:
-                    print('Found commands:', commands)
-                else:
-                    print('Not commands')
+                # Search for setup.py if there is
+                entries = __os.listdir(new_git_folder)
+                for filen in entries:
+                    file_to_read = __os.path.join( new_git_folder, filen )
+                    setup_content = readFileAsString( file_to_read )
+                    commands = []
+                    find_for = [ '--' ]
+                    for finding in find_for:
+                        if finding in setup_content:
+                            for ind in findIndexAllOccurrencesSubstring(finding, str( setup_content )):
+                                interesting_line = str(setup_content)[ind:].split('\n')[0]
+                                for appearances in interesting_line.split( finding ):
+                                    comm = ''.join( [ finding, appearances.split('\'')[0] ] ).split(' ')[0]
+                                    if not comm in commands and not comm == finding:
+                                        commands.append( comm )
+                    if commands:
+                        print('Found commands:', commands)
+                    else:
+                        print('Not commands')
+            else:
+                Logger.printMessage('Not exists', description=moduleDir, is_error=True)
+                ht.__removeModule__(moduleName, category)
         else:
-            Logger.printMessage('Not exists', description=moduleDir, is_error=True)
-            ht.__removeModule__(moduleName, category)
+            Logger.printMessage('Not working ir ARM', description=moduleDir, is_error=True)
     except Exception as e:
         raise
         Logger.printMessage(str(e), is_error=True)
